@@ -86,9 +86,8 @@ gchar *msg
 ){
   GtkWidget *box;
 
-  box = gnome_message_box_new(msg,
-			      GNOME_MESSAGE_BOX_INFO, 
-			      GNOME_STOCK_BUTTON_OK, NULL);
+  box = gnome_app_message (GNOME_APP(app),
+                           msg);
 
   gtk_window_set_modal(GTK_WINDOW(box), TRUE);
   gtk_widget_show(box);
@@ -629,7 +628,7 @@ void init_game(
 
   create_game_timer();
 
-  gtk_signal_connect(GTK_OBJECT(app), "key_press_event",
+  g_signal_connect(GTK_OBJECT(app), "key_press_event",
 		     GTK_SIGNAL_FUNC(keyboard_cb), 0);  
 }
 
@@ -654,11 +653,16 @@ void cleanup_game(
  **/
 void start_new_game(
 ){
+  GameConfig *conf;
   current_level = 0;
   score = 0;
   kills = 0;
   score_step = 0;
-  safe_teleports = game_config()->initial_safe_teleports;
+
+  conf = game_config();
+  g_return_if_fail (conf != NULL);
+
+  safe_teleports = conf->initial_safe_teleports;
 
   remove_bubble();
   reset_player_animation();
